package com.sinenux.yshub.config;

import com.bluebird.core.tool.utils.Func;
import com.bluebird.core.tool.utils.WebUtil;
import lombok.extern.slf4j.Slf4j;
import org.jetbrains.annotations.NotNull;
import org.springframework.web.servlet.HandlerInterceptor;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;
import java.util.List;

@Slf4j
public class IpWhitelistInterceptor implements HandlerInterceptor {

    //    private final List<String> allowedIpList = Arrays.asList("127.0.0.1", "192.168.1.100", "192.168.1.101");
    private final String ips;

    public IpWhitelistInterceptor(String ips) {
        this.ips = ips;
    }

    @Override
    public boolean preHandle(HttpServletRequest request, @NotNull HttpServletResponse response, @NotNull Object handler) {
        if (Func.isBlank(ips) || Func.equals("0.0.0.0", ips)) {
            return true;
        }
        log.info("SN-HUB ===================== IP白名单 为 {}", ips);

        String[] ipArray = Func.split(ips, ",");
        List<String> allowedIpList = Arrays.asList(ipArray);

        String requestIp = WebUtil.getIP(request);
        log.info("SN-HUB ===================== 请求IP 为 {}", requestIp);
        if (!allowedIpList.contains(requestIp)) {
            response.setStatus(HttpServletResponse.SC_FORBIDDEN);
            return false; // 不允许访问
        }
        return true; // 允许访问
    }

}
