package com.sinenux.yshub.config;

import com.baomidou.mybatisplus.extension.spring.MybatisSqlSessionFactoryBean;
import com.bluebird.core.tool.utils.Func;
import com.dream.drive.factory.DriveDataSourceFactory;
import com.dream.system.datasource.DataSourceFactory;
import com.zaxxer.hikari.HikariDataSource;
import lombok.extern.slf4j.Slf4j;
import org.apache.ibatis.session.SqlSessionFactory;
import org.mybatis.spring.annotation.MapperScan;
import org.mybatis.spring.transaction.SpringManagedTransactionFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import javax.sql.DataSource;
import java.sql.SQLException;

@Configuration
@Slf4j
@MapperScan("com.sinenux.yshub.mapper")
public class MysqlConfig {
    @Value("${MYSQL_URL}")
    private String url;
    @Value("${MYSQL_USERNAME}")
    private String username;
    @Value("${MYSQL_PASSWORD}")
    private String password;

    @Bean
    public DataSource mySqlDataSource() throws SQLException {
        HikariDataSource dataSource = new HikariDataSource();
        dataSource.setJdbcUrl(url);
        dataSource.setUsername(username);
        dataSource.setPassword(password);
        dataSource.setDriverClassName("com.mysql.cj.jdbc.Driver");
        if (Func.isNotEmpty(url)) {
            dataSource.getConnection().close();
        }

        return dataSource;
    }

    @Bean
    public SqlSessionFactory sqlSessionFactory(DataSource dataSource) throws Exception {
        MybatisSqlSessionFactoryBean sqlSessionFactory = new MybatisSqlSessionFactoryBean();
        sqlSessionFactory.setDataSource(dataSource);
        sqlSessionFactory.setTypeAliasesPackage("com.sinenux.snhub.entity");

        sqlSessionFactory.setTransactionFactory(new SpringManagedTransactionFactory());

        return sqlSessionFactory.getObject();
    }

    @Bean
    public DataSourceFactory dataSourceFactory(DataSource dataSource) {
        return new DriveDataSourceFactory(dataSource);
    }


}
