package com.sinenux.yshub.controller;

import com.bluebird.core.tool.api.R;
import com.sinenux.yshub.entity.EnterprisePrefix;
import com.sinenux.yshub.service.IEnterprisePrefixService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 告警记录 控制器
 *
 * @author wtc
 * @since 2023-05-24
 */
@RestController
@AllArgsConstructor
@RequestMapping("/enterprise/prefix")
@Api(value = "企业前缀", tags = "企业前缀接口")
public class EnterprisePrefixController {

    private final IEnterprisePrefixService enterprisePrefixService;

    /**
     * 企业前缀top10
     */
    @GetMapping("/top")
    @ApiOperation(value = "企业前缀top10", notes = "企业前缀top10")
    public R<List<EnterprisePrefix>> prefixTop() {
        List<EnterprisePrefix> list = enterprisePrefixService.getTop10();
        return R.data(list);
    }

    /**
     * 获取所有企业名称
     */
    @GetMapping("/allName")
    @ApiOperation(value = "所有企业名称", notes = "所有企业名称")
    public R<List<String>> list() {
        List<String> list = enterprisePrefixService.lambdaQuery()
                .select(EnterprisePrefix::getEntName)
                .eq(EnterprisePrefix::getState, 1)
                .list()
                .stream()
                .map(EnterprisePrefix::getEntName)
                .collect(Collectors.toList());
        return R.data(list);
    }

    /**
     * 获取当前注册量，以及昨日注册量，增长量
     */
    @GetMapping("/statistics")
    @ApiOperation(value = "前缀注册量统计", notes = "前缀注册量统计")
    public R<Map<String, Object>> statistics() {
        Map<String, Object> map = enterprisePrefixService.prefixStatistics();
        return R.data(map);
    }
}
