package com.sinenux.yshub.utils;

import com.bluebird.core.tool.utils.ConcurrentDateFormat;
import com.bluebird.core.tool.utils.DateUtil;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

/**
 * 日期工具类(补充)
 *
 * @author cgm
 * @date 2022/2/15 17:17
 */
public class MyDateUtil {
	public static final ConcurrentDateFormat YEAR_FORMAT = ConcurrentDateFormat.of("yyyy");
	public static final ConcurrentDateFormat MONTH_FORMAT = ConcurrentDateFormat.of("yyyyMM");

	public static String formatYear(Date date) {
		return YEAR_FORMAT.format(date);
	}

	public static String formatMonth(Date date) {
		return MONTH_FORMAT.format(date);
	}

	/**
	 * 获取当月所有日期
	 */
	public static List<Date> getAllDateOfTheMonth(Date date) {
		List<Date> list = new ArrayList<>();

		Calendar calendar = Calendar.getInstance();
		calendar.setTime(date);
		calendar.set(Calendar.DATE, 1);

		int month = calendar.get(Calendar.MONTH);
		while (calendar.get(Calendar.MONTH) == month) {
			list.add(calendar.getTime());
			calendar.add(Calendar.DATE, 1);
		}

		return list;
	}

	/**
	 * 将当前时间 分秒归零
	 */
	public static Date getDateOfMinute(Date date) {
		Calendar calendar = Calendar.getInstance();
		calendar.setTime(date);
		calendar.set(Calendar.MINUTE, 0);
		calendar.set(Calendar.SECOND, 0);
		calendar.set(Calendar.MILLISECOND, 0);
		String time = DateUtil.formatDateTime(calendar.getTime());
		return DateUtil.parse(time, DateUtil.DATETIME_FORMAT);
	}

	/**
	 * 将当前时间 时分秒归零
	 */
	public static Date getDateOfHour(Date date) {
		Calendar calendar = Calendar.getInstance();
		calendar.setTime(date);
		calendar.set(Calendar.HOUR_OF_DAY, 0);
		calendar.set(Calendar.MINUTE, 0);
		calendar.set(Calendar.SECOND, 0);
		calendar.set(Calendar.MILLISECOND, 0);
		String time = DateUtil.formatDateTime(calendar.getTime());
		return DateUtil.parse(time, DateUtil.DATETIME_FORMAT);
	}

	/**
	 * 将yyyy-mm-dd格式 或者 yyyy-MM 格式 转换成 yyyy-MM-dd HH:mm:ss
	 *
	 * @param
	 * @return
	 */
	public static String formatShortTimeToLong(String shortTimeStr) {
		if (shortTimeStr == null) {
			return null;
		}
		// 定义SimpleDateFormat的格式
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");

		// 解析日期字符串
		Date date = null;
		try {
			date = sdf.parse(shortTimeStr);
		} catch (ParseException e) {
			return null;
		}

		// 将Date转换为带时间的字符串格式并返回
		SimpleDateFormat sdf2 = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
		return sdf2.format(date);
	}
}
